@@ -697,7 +697,7 @@ func NewGui(
 			return gui.helpers.AppStatus.WithWaitingStatusSync(message, f)
 		},
 		func(message string, kind types.ToastKind) { gui.helpers.AppStatus.Toast(message, kind) },
-		func() string { return gui.Views.Confirmation.TextArea.GetContent() },
+		func() string { return gui.Views.Prompt.TextArea.GetContent() },
 		func() bool { return gui.c.InDemo() },
 	)
 
@@ -848,6 +848,8 @@ func (gui *Gui) Run(startArgs appTypes.StartArgs) error {
 
 	gui.BackgroundRoutineMgr.startBackgroundRoutines()
 
+	gui.Helpers().SuspendResume.InstallResumeSignalHandler()
+
 	gui.c.Log.Info("starting main loop")
 
 	// setting here so we can use it in layout.go
@@ -899,21 +901,36 @@ func (gui *Gui) runSubprocessWithSuspenseAndRefresh(subprocess *oscommands.CmdOb
 	return nil
 }
 
+func (gui *Gui) suspend() error {
+	if err := gui.g.Suspend(); err != nil {
+		return err
+	}
+
+	gui.BackgroundRoutineMgr.PauseBackgroundRefreshes(true)
+	return nil
+}
+
+func (gui *Gui) resume() error {
+	if err := gui.g.Resume(); err != nil {
+		return err
+	}
+
+	gui.BackgroundRoutineMgr.PauseBackgroundRefreshes(false)
+	return nil
+}
+
 // returns whether command exited without error or not
 func (gui *Gui) runSubprocessWithSuspense(subprocess *oscommands.CmdObj) (bool, error) {
 	gui.Mutexes.SubprocessMutex.Lock()
 	defer gui.Mutexes.SubprocessMutex.Unlock()
 
-	if err := gui.g.Suspend(); err != nil {
+	if err := gui.suspend(); err != nil {
 		return false, err
 	}
 
-	gui.BackgroundRoutineMgr.PauseBackgroundRefreshes(true)
-	defer gui.BackgroundRoutineMgr.PauseBackgroundRefreshes(false)
-
 	cmdErr := gui.runSubprocess(subprocess)
 
-	if err := gui.g.Resume(); err != nil {
+	if err := gui.resume(); err != nil {
 		return false, err
 	}
 
