@@ -2,19 +2,25 @@ package presentation
 
 import (
 	"fmt"
+	"sync/atomic"
 	"testing"
 	"time"
 
 	"github.com/gookit/color"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
+	"github.com/jesseduffield/lazygit/pkg/common"
 	"github.com/jesseduffield/lazygit/pkg/gui/presentation/icons"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
-	"github.com/jesseduffield/lazygit/pkg/utils"
 	"github.com/samber/lo"
 	"github.com/stretchr/testify/assert"
 	"github.com/xo/terminfo"
 )
 
+func makeAtomic(v int32) (result atomic.Int32) {
+	result.Store(v)
+	return //nolint: nakedret
+}
+
 func Test_getBranchDisplayStrings(t *testing.T) {
 	scenarios := []struct {
 		branch               *models.Branch
@@ -23,6 +29,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 		viewWidth            int
 		useIcons             bool
 		checkedOutByWorktree bool
+		showDivergenceCfg    string
 		expected             []string
 	}{
 		// First some tests for when the view is wide enough so that everything fits:
@@ -33,8 +40,19 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            100,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "branch_name"},
 		},
+		{
+			branch:               &models.Branch{Name: "🍉_special_char", Recency: "1m"},
+			itemOperation:        types.ItemOperationNone,
+			fullDescription:      false,
+			viewWidth:            19,
+			useIcons:             false,
+			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
+			expected:             []string{"1m", "🍉_special_char"},
+		},
 		{
 			branch:               &models.Branch{Name: "branch_name", Recency: "1m"},
 			itemOperation:        types.ItemOperationNone,
@@ -42,6 +60,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            100,
 			useIcons:             false,
 			checkedOutByWorktree: true,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "branch_name (worktree)"},
 		},
 		{
@@ -51,6 +70,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            100,
 			useIcons:             true,
 			checkedOutByWorktree: true,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "󰘬", "branch_name 󰌹"},
 		},
 		{
@@ -66,6 +86,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            100,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "branch_name ✓"},
 		},
 		{
@@ -81,7 +102,56 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            100,
 			useIcons:             false,
 			checkedOutByWorktree: true,
-			expected:             []string{"1m", "branch_name (worktree) ↑3↓5"},
+			showDivergenceCfg:    "none",
+			expected:             []string{"1m", "branch_name (worktree) ↓5↑3"},
+		},
+		{
+			branch: &models.Branch{
+				Name:             "branch_name",
+				Recency:          "1m",
+				BehindBaseBranch: makeAtomic(2),
+			},
+			itemOperation:        types.ItemOperationNone,
+			fullDescription:      false,
+			viewWidth:            20,
+			useIcons:             false,
+			checkedOutByWorktree: false,
+			showDivergenceCfg:    "onlyArrow",
+			expected:             []string{"1m", "branch_name    ↓"},
+		},
+		{
+			branch: &models.Branch{
+				Name:             "branch_name",
+				Recency:          "1m",
+				UpstreamRemote:   "origin",
+				AheadForPull:     "0",
+				BehindForPull:    "0",
+				BehindBaseBranch: makeAtomic(2),
+			},
+			itemOperation:        types.ItemOperationNone,
+			fullDescription:      false,
+			viewWidth:            22,
+			useIcons:             false,
+			checkedOutByWorktree: false,
+			showDivergenceCfg:    "arrowAndNumber",
+			expected:             []string{"1m", "branch_name ✓   ↓2"},
+		},
+		{
+			branch: &models.Branch{
+				Name:             "branch_name",
+				Recency:          "1m",
+				UpstreamRemote:   "origin",
+				AheadForPull:     "3",
+				BehindForPull:    "5",
+				BehindBaseBranch: makeAtomic(2),
+			},
+			itemOperation:        types.ItemOperationNone,
+			fullDescription:      false,
+			viewWidth:            26,
+			useIcons:             false,
+			checkedOutByWorktree: false,
+			showDivergenceCfg:    "arrowAndNumber",
+			expected:             []string{"1m", "branch_name ↓5↑3    ↓2"},
 		},
 		{
 			branch:               &models.Branch{Name: "branch_name", Recency: "1m"},
@@ -90,6 +160,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            100,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "branch_name Pushing |"},
 		},
 		{
@@ -108,6 +179,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            100,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "12345678", "branch_name ✓", "origin branch_name", "commit title"},
 		},
 
@@ -119,8 +191,19 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            14,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "branch_na…"},
 		},
+		{
+			branch:               &models.Branch{Name: "🍉_special_char", Recency: "1m"},
+			itemOperation:        types.ItemOperationNone,
+			fullDescription:      false,
+			viewWidth:            18,
+			useIcons:             false,
+			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
+			expected:             []string{"1m", "🍉_special_ch…"},
+		},
 		{
 			branch:               &models.Branch{Name: "branch_name", Recency: "1m"},
 			itemOperation:        types.ItemOperationNone,
@@ -128,6 +211,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            14,
 			useIcons:             false,
 			checkedOutByWorktree: true,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "bra… (worktree)"},
 		},
 		{
@@ -137,6 +221,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            14,
 			useIcons:             true,
 			checkedOutByWorktree: true,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "󰘬", "branc… 󰌹"},
 		},
 		{
@@ -152,8 +237,26 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            14,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "branch_… ✓"},
 		},
+		{
+			branch: &models.Branch{
+				Name:             "branch_name",
+				Recency:          "1m",
+				UpstreamRemote:   "origin",
+				AheadForPull:     "3",
+				BehindForPull:    "5",
+				BehindBaseBranch: makeAtomic(4),
+			},
+			itemOperation:        types.ItemOperationNone,
+			fullDescription:      false,
+			viewWidth:            21,
+			useIcons:             false,
+			checkedOutByWorktree: false,
+			showDivergenceCfg:    "arrowAndNumber",
+			expected:             []string{"1m", "branch_n… ↓5↑3 ↓4"},
+		},
 		{
 			branch: &models.Branch{
 				Name:           "branch_name",
@@ -167,7 +270,8 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            30,
 			useIcons:             false,
 			checkedOutByWorktree: true,
-			expected:             []string{"1m", "branch_na… (worktree) ↑3↓5"},
+			showDivergenceCfg:    "none",
+			expected:             []string{"1m", "branch_na… (worktree) ↓5↑3"},
 		},
 		{
 			branch:               &models.Branch{Name: "branch_name", Recency: "1m"},
@@ -176,6 +280,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            20,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "branc… Pushing |"},
 		},
 		{
@@ -185,6 +290,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            -1,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "abc Pushing |"},
 		},
 		{
@@ -194,6 +300,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            -1,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "ab Pushing |"},
 		},
 		{
@@ -203,6 +310,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            -1,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "a Pushing |"},
 		},
 		{
@@ -221,6 +329,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 			viewWidth:            20,
 			useIcons:             false,
 			checkedOutByWorktree: false,
+			showDivergenceCfg:    "none",
 			expected:             []string{"1m", "12345678", "bran… ✓", "origin branch_name", "commit title"},
 		},
 	}
@@ -228,10 +337,12 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 	oldColorLevel := color.ForceSetColorLevel(terminfo.ColorLevelNone)
 	defer color.ForceSetColorLevel(oldColorLevel)
 
-	c := utils.NewDummyCommon()
+	c := common.NewDummyCommon()
+	SetCustomBranches(c.UserConfig().Gui.BranchColorPatterns, true)
 
 	for i, s := range scenarios {
 		icons.SetNerdFontsVersion(lo.Ternary(s.useIcons, "3", ""))
+		c.UserConfig().Gui.ShowDivergenceFromBaseBranch = s.showDivergenceCfg
 
 		worktrees := []*models.Worktree{}
 		if s.checkedOutByWorktree {
@@ -239,7 +350,7 @@ func Test_getBranchDisplayStrings(t *testing.T) {
 		}
 
 		t.Run(fmt.Sprintf("getBranchDisplayStrings_%d", i), func(t *testing.T) {
-			strings := getBranchDisplayStrings(s.branch, s.itemOperation, s.fullDescription, false, s.viewWidth, c.Tr, c.UserConfig, worktrees, time.Time{})
+			strings := getBranchDisplayStrings(s.branch, s.itemOperation, s.fullDescription, false, s.viewWidth, c.Tr, c.UserConfig(), worktrees, time.Time{})
 			assert.Equal(t, s.expected, strings)
 		})
 	}
