@@ -235,6 +235,10 @@ func (self *Shell) DeleteFileAndAdd(fileName string) *Shell {
 		GitAdd(fileName)
 }
 
+func (self *Shell) RenameFileInGit(oldName string, newName string) *Shell {
+	return self.RunCommand([]string{"git", "mv", oldName, newName})
+}
+
 // creates commits 01, 02, 03, ..., n with a new file in each
 // The reason for padding with zeroes is so that it's easier to do string
 // matches on the commit messages when there are many of them
@@ -257,7 +261,7 @@ func (self *Shell) CreateNCommitsStartingAt(n, startIndex int) *Shell {
 // Only to be used in demos, because the list might change and we don't want
 // tests to break when it does.
 func (self *Shell) CreateNCommitsWithRandomMessages(n int) *Shell {
-	for i := 0; i < n; i++ {
+	for i := range n {
 		file := RandomFiles[i]
 		self.CreateFileAndAdd(
 			file.Name,
@@ -286,7 +290,7 @@ func (self *Shell) CreateRepoHistory() *Shell {
 	totalCommits := 0
 
 	// Generate commits
-	for i := 0; i < numInitialCommits; i++ {
+	for i := range numInitialCommits {
 		author := authors[i%numAuthors]
 		commitMessage := RandomCommitMessages[totalCommits%len(RandomCommitMessages)]
 
@@ -296,7 +300,7 @@ func (self *Shell) CreateRepoHistory() *Shell {
 	}
 
 	// Generate branches and merges
-	for i := 0; i < numBranches; i++ {
+	for i := range numBranches {
 		// We'll have one author creating all the commits in the branch
 		author := authors[i%numAuthors]
 		branchName := RandomBranchNames[i%len(RandomBranchNames)]
@@ -309,7 +313,7 @@ func (self *Shell) CreateRepoHistory() *Shell {
 		self.NewBranchFrom(branchName, fmt.Sprintf("master~%d", commitOffset))
 
 		numCommitsInBranch := rand.Intn(maxCommitsPerBranch) + 1
-		for j := 0; j < numCommitsInBranch; j++ {
+		for range numCommitsInBranch {
 			commitMessage := RandomCommitMessages[totalCommits%len(RandomCommitMessages)]
 
 			self.SetAuthor(author, "")
@@ -360,8 +364,8 @@ func (self *Shell) CloneIntoRemote(name string) *Shell {
 }
 
 func (self *Shell) CloneIntoSubmodule(submoduleName string, submodulePath string) *Shell {
-	self.Clone("other_repo")
-	self.RunCommand([]string{"git", "submodule", "add", "--name", submoduleName, "../other_repo", submodulePath})
+	self.Clone(submoduleName)
+	self.RunCommand([]string{"git", "submodule", "add", "--name", submoduleName, "../" + submoduleName, submodulePath})
 
 	return self
 }
