@@ -10,10 +10,12 @@ var RebaseAndDrop = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Rebase onto another branch, deal with the conflicts. Also mark a commit to be dropped before continuing.",
 	ExtraCmdArgs: []string{},
 	Skip:         false,
-	SetupConfig:  func(config *config.AppConfig) {},
+	SetupConfig: func(config *config.AppConfig) {
+		config.GetUserConfig().Git.LocalBranchSortOrder = "recency"
+	},
 	SetupRepo: func(shell *Shell) {
 		shared.MergeConflictsSetup(shell)
-		// addin a couple additional commits so that we can drop one
+		// adding a couple additional commits so that we can drop one
 		shell.EmptyCommit("to remove")
 		shell.EmptyCommit("to keep")
 	},
@@ -51,9 +53,11 @@ var RebaseAndDrop = NewIntegrationTest(NewIntegrationTestArgs{
 		t.Views().Commits().
 			Focus().
 			TopLines(
+				Contains("--- Pending rebase todos ---"),
 				MatchesRegexp(`pick.*to keep`).IsSelected(),
 				MatchesRegexp(`pick.*to remove`),
-				MatchesRegexp(`conflict.*YOU ARE HERE.*first change`),
+				MatchesRegexp(`pick.*CONFLICT.*first change`),
+				Contains("--- Commits ---"),
 				MatchesRegexp("second-change-branch unrelated change"),
 				MatchesRegexp("second change"),
 				MatchesRegexp("original"),
@@ -61,9 +65,11 @@ var RebaseAndDrop = NewIntegrationTest(NewIntegrationTestArgs{
 			SelectNextItem().
 			Press(keys.Universal.Remove).
 			TopLines(
+				Contains("--- Pending rebase todos ---"),
 				MatchesRegexp(`pick.*to keep`),
 				MatchesRegexp(`drop.*to remove`).IsSelected(),
-				MatchesRegexp(`conflict.*YOU ARE HERE.*first change`),
+				MatchesRegexp(`pick.*CONFLICT.*first change`),
+				Contains("--- Commits ---"),
 				MatchesRegexp("second-change-branch unrelated change"),
 				MatchesRegexp("second change"),
 				MatchesRegexp("original"),
@@ -77,7 +83,7 @@ var RebaseAndDrop = NewIntegrationTest(NewIntegrationTestArgs{
 			IsFocused().
 			PressPrimaryAction()
 
-		t.Common().ContinueOnConflictsResolved()
+		t.Common().ContinueOnConflictsResolved("rebase")
 
 		t.Views().Information().Content(DoesNotContain("Rebasing"))
 
