@@ -23,15 +23,14 @@ var EditNonTodoCommitDuringRebase = NewIntegrationTest(NewIntegrationTestArgs{
 			).
 			Press(keys.Universal.Edit).
 			Lines(
-				Contains("<-- YOU ARE HERE --- commit 02"),
+				Contains("--- Pending rebase todos ---"),
+				Contains("--- Commits ---"),
+				Contains("commit 02"),
 				Contains("commit 01"),
 			).
 			NavigateToLine(Contains("commit 01")).
 			Press(keys.Universal.Edit)
 
-		t.ExpectPopup().Alert().
-			Title(Equals("Error")).
-			Content(Contains("Can't perform this action during a rebase")).
-			Confirm()
+		t.ExpectToast(Contains("Disabled: When rebasing, this action only works on a selection of TODO commits."))
 	},
 })
