@@ -7,7 +7,7 @@ import (
 
 var StashUnstaged = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Stash unstaged changes",
-	ExtraCmdArgs: "",
+	ExtraCmdArgs: []string{},
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
 	SetupRepo: func(shell *Shell) {
@@ -23,12 +23,13 @@ var StashUnstaged = NewIntegrationTest(NewIntegrationTestArgs{
 
 		t.Views().Files().
 			Lines(
-				Contains("file-staged"),
-				Contains("file-unstaged"),
+				Equals("▼ /"),
+				Equals("  M  file-staged"),
+				Equals("   M file-unstaged"),
 			).
 			Press(keys.Files.ViewStashOptions)
 
-		t.ExpectPopup().Menu().Title(Equals("Stash options")).Select(MatchesRegexp("stash unstaged changes$")).Confirm()
+		t.ExpectPopup().Menu().Title(Equals("Stash options")).Select(MatchesRegexp("Stash unstaged changes$")).Confirm()
 
 		t.ExpectPopup().Prompt().Title(Equals("Stash changes")).Type("my stashed file").Confirm()
 
